@@ -62,9 +62,10 @@ enum Unit {
     UnitPetaHertz = MetricPrefixPeta + UnitHertz,
 
     // Time units.
-    UnitBootTimestamp = 400, // deprecated
+    UnitBootTimestamp = 400,
     UnitSecond,
     UnitTime,
+    UnitTicks,
 
     // Misc units.
     UnitCelsius = 500,
