@@ -35,7 +35,6 @@ public:
         mIsLocalHost = true;
         mProcesses.insert(-1, &mFakeProcess);
         mElapsedTimeMilliSeconds = 0;
-        mHavePreviousIoValues = false;
         mUpdateFlags = {};
         mUsingHistoricalData = false;
         mLastError = Error::NoError;
@@ -59,7 +58,6 @@ public:
     long mElapsedTimeMilliSeconds; ///< The number of milliseconds  (1000ths of a second) that passed since the last update
 
     Processes::UpdateFlags mUpdateFlags;
-    bool mHavePreviousIoValues; ///< This is whether we updated the IO value on the last update
     bool mUsingHistoricalData; ///< Whether to return historical data for updateProcess() etc
     Processes *q;
 
@@ -127,12 +125,12 @@ bool Processes::updateProcess(Process *ps, long ppid)
     Q_ASSERT(parent); // even init has a non-null parent - the mFakeProcess
 
     if (ps->parent() != parent) {
-        emit beginMoveProcess(ps, parent /*new parent*/);
+        Q_EMIT beginMoveProcess(ps, parent /*new parent*/);
         // Processes has been reparented
         Process *p = ps;
         do {
             p = p->parent();
-            p->numChildren()--;
+            p->numChildren() -= (ps->numChildren() + 1);
         } while (p->pid() != -1);
         Q_ASSERT(ps != parent);
         ps->parent()->children().removeAll(ps);
@@ -141,9 +139,9 @@ bool Processes::updateProcess(Process *ps, long ppid)
         p = ps;
         do {
             p = p->parent();
-            p->numChildren()++;
+            p->numChildren() += (ps->numChildren() + 1);
         } while (p->pid() != -1);
-        emit endMoveProcess();
+        Q_EMIT endMoveProcess();
         Q_ASSERT(ps != parent);
         ps->setParent(parent);
     }
@@ -151,7 +149,7 @@ bool Processes::updateProcess(Process *ps, long ppid)
     ps->setParentPid(ppid);
 
     bool success = updateProcessInfo(ps);
-    emit processChanged(ps, false);
+    Q_EMIT processChanged(ps, false);
 
     return success;
 }
@@ -196,23 +194,27 @@ bool Processes::updateProcessInfo(Process *ps)
         int elapsedTime = ps->elapsedTimeMilliSeconds();
         ps->setElapsedTimeMilliSeconds(d->mLastUpdated.elapsed());
         elapsedTime = ps->elapsedTimeMilliSeconds() - elapsedTime + d->mElapsedTimeMilliSeconds;
-        if (elapsedTime) {
+        if (elapsedTime > 0) {
             ps->setUserUsage((int)(((ps->userTime() - oldUserTime) * 1000.0) / elapsedTime));
             ps->setSysUsage((int)(((ps->sysTime() - oldSysTime) * 1000.0) / elapsedTime));
         }
 #endif
+
+        static auto calculateRate = [](qlonglong current, qlonglong previous, int elapsedTime) {
+            if (elapsedTime <= 0 || previous <= 0) {
+                return 0.0;
+            }
+            return (current - previous) * 1000.0 / elapsedTime;
+        };
+
         if (d->mUpdateFlags.testFlag(Processes::IOStatistics)) {
-            if (d->mHavePreviousIoValues) {
-                ps->setIoCharactersReadRate((ps->ioCharactersRead() - oldIoCharactersRead) * 1000.0 / elapsedTime);
-                ps->setIoCharactersWrittenRate((ps->ioCharactersWritten() - oldIoCharactersWritten) * 1000.0 / elapsedTime);
-                ps->setIoReadSyscallsRate((ps->ioReadSyscalls() - oldIoReadSyscalls) * 1000.0 / elapsedTime);
-                ps->setIoWriteSyscallsRate((ps->ioWriteSyscalls() - oldIoWriteSyscalls) * 1000.0 / elapsedTime);
-                ps->setIoCharactersActuallyReadRate((ps->ioCharactersActuallyRead() - oldIoCharactersActuallyRead) * 1000.0 / elapsedTime);
-                ps->setIoCharactersActuallyWrittenRate((ps->ioCharactersActuallyWritten() - oldIoCharactersActuallyWritten) * 1000.0 / elapsedTime);
-            } else
-                d->mHavePreviousIoValues = true;
-        } else if (d->mHavePreviousIoValues) {
-            d->mHavePreviousIoValues = false;
+            ps->setIoCharactersReadRate(calculateRate(ps->ioCharactersRead(), oldIoCharactersRead, elapsedTime));
+            ps->setIoCharactersWrittenRate(calculateRate(ps->ioCharactersWritten(), oldIoCharactersWritten, elapsedTime));
+            ps->setIoReadSyscallsRate(calculateRate(ps->ioReadSyscalls(), oldIoReadSyscalls, elapsedTime));
+            ps->setIoWriteSyscallsRate(calculateRate(ps->ioWriteSyscalls(), oldIoWriteSyscalls, elapsedTime));
+            ps->setIoCharactersActuallyReadRate(calculateRate(ps->ioCharactersActuallyRead(), oldIoCharactersActuallyRead, elapsedTime));
+            ps->setIoCharactersActuallyWrittenRate(calculateRate(ps->ioCharactersActuallyWritten(), oldIoCharactersActuallyWritten, elapsedTime));
+        } else {
             ps->setIoCharactersReadRate(0);
             ps->setIoCharactersWrittenRate(0);
             ps->setIoReadSyscallsRate(0);
@@ -229,7 +231,7 @@ bool Processes::updateProcessInfo(Process *ps)
             while (p->pid() != -1) {
                 p->totalUserUsage() += ps->userUsage();
                 p->totalSysUsage() += ps->sysUsage();
-                emit processChanged(p, true);
+                Q_EMIT processChanged(p, true);
                 p = p->parent();
             }
         }
@@ -250,7 +252,7 @@ bool Processes::addProcess(long pid, long ppid)
     // it's a new process - we need to set it up
     Process *ps = new Process(pid, ppid, parent);
 
-    emit beginAddProcess(ps);
+    Q_EMIT beginAddProcess(ps);
 
     d->mProcesses.insert(pid, ps);
 
@@ -268,7 +270,7 @@ bool Processes::addProcess(long pid, long ppid)
 
     // Now we can actually get the process info
     bool success = updateProcessInfo(ps);
-    emit endAddProcess();
+    Q_EMIT endAddProcess();
     return success;
 }
 bool Processes::updateOrAddProcess(long pid)
@@ -351,7 +353,7 @@ void Processes::processesUpdated()
         d->mEndedProcesses = endedProcesses;
     }
 
-    emit updated();
+    Q_EMIT updated();
 }
 
 void Processes::processUpdated(long pid, const Process::Updates &changes)
@@ -382,7 +384,7 @@ void Processes::Private::markProcessesAsEnded(long pid)
     if (!process)
         return;
     process->setStatus(Process::Ended);
-    emit q->processChanged(process, false);
+    Q_EMIT q->processChanged(process, false);
 }
 void Processes::deleteProcess(long pid)
 {
@@ -395,7 +397,7 @@ void Processes::deleteProcess(long pid)
         deleteProcess(it->pid());
     }
 
-    emit beginRemoveProcess(process);
+    Q_EMIT beginRemoveProcess(process);
 
     d->mProcesses.remove(pid);
     d->mListProcesses.removeAll(process);
@@ -418,7 +420,7 @@ void Processes::deleteProcess(long pid)
     }
 
     delete process;
-    emit endRemoveProcess();
+    Q_EMIT endRemoveProcess();
 }
 
 bool Processes::killProcess(long pid)
