@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC *.ui >> rc.cpp
-$XGETTEXT *.cpp -o $podir/processui.pot
+$XGETTEXT `find . -name \*.cpp` -o $podir/processui.pot
 rm -f rc.cpp
