@@ -1,21 +1,8 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
-    Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
@@ -136,8 +123,8 @@ public:
     enum class Status {
         Unknown, ///< The sensor has no ID assigned.
         Loading, ///< The sensor is currently being loaded.
-        Ready,   ///< The sensor has been loaded.
-        Error,   ///< An error occurred or the sensor has been removed.
+        Ready, ///< The sensor has been loaded.
+        Error, ///< An error occurred or the sensor has been removed.
         Removed, ///< Removed from backend
     };
     Q_ENUM(Status)
